@@ -38,4 +38,11 @@ typedef struct _registers * __pregisters;
 
 typedef __u32 __pptr;
 
+struct _mminit {
+	__u16 cs, endcs, ds, endds, ss, endss, lowss;
+};
+
+typedef struct _mminit __arch_mminit;
+typedef struct _mminit * __parch_mminit;
+
 #endif
