@@ -1,7 +1,7 @@
 #ifndef LINUXMT_SCHED_H
 #define LINUXMT_SCHED_H
 
-#define MAX_TASKS 4
+#define MAX_TASKS 8
 
 struct _task {
 /* Executive stuff */
@@ -10,7 +10,7 @@ struct _task {
 	__pptr t_begcode, t_endcode, t_begdata, t_enddata, t_begstack, t_endstack; 
 /* Scheduling + status variables */
 	__s16 t_state;
-	__uint t_counter, t_priority;	/* Valuable scheduling elements */
+	__uint t_count, t_priority;	/* Valuable scheduling elements */
 	__u16 t_flags; /* Not defined yet */
 	__u16 t_errno; /* Last error */
 };
@@ -25,10 +25,16 @@ typedef struct _task * __ptask;
 
 __task task[MAX_TASKS];
 
+#define IDLE_TASK 0
+#define SCHED_TASK 1
+#define FORK_TASK 2
+
 extern __ptask CURRENT, NEXT;
+extern __ptask FORK_FROM, FORK_TO;
+extern __uint CURNUM;
 
 _FUNCTION(__uint build_task, ());
-_FUNCTION(__uint load_task, (__ptask ptask));
+_FUNCTION(__uint alloc_task, (__ptask ptask));
 _FUNCTION(void schedule, ()); 
 
 #endif
